==> tutti-ui-swing-1.0-sources.jar: fr/ifremer/tutti/ui/swing/UpdateReferentialAction.java <==
package fr.ifremer.tutti.ui.swing;

/*
 * #%L
 * Tutti :: UI
 * $Id: UpdateReferentialAction.java 438 2013-02-18 07:40:56Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.0/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/UpdateReferentialAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.persistence.ProgressionModel;
import fr.ifremer.tutti.ui.swing.config.TuttiApplicationConfig;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.nuiton.util.ApplicationUpdater;

import java.awt.event.ActionEvent;
import java.io.File;

import static org.nuiton.i18n.I18n._;

/**
 * To update referential using the {@link ApplicationUpdater} mecanism.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class UpdateReferentialAction extends AbstractMainUITuttiAction {

    private static final long serialVersionUID = 1L;

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(UpdateReferentialAction.class);

    public UpdateReferentialAction(MainUIHandler handler) {
        super(handler,
              "updateReferential",
              "update-referential",
              _("tutti.action.updateReferential"),
              _("tutti.action.updateReferential.tip"),
              true);
    }

    @Override
    protected void doAction(ActionEvent event) {
        TuttiApplicationConfig config = getContext().getConfig();

        File current = config.getDataDirectory();
        String url = config.getUpdateUrl();

        if (log.isInfoEnabled()) {
            log.info(String.format("Try to update db (current data location: %s), using update url: %s", current, url));
        }
        ApplicationUpdater up = new ApplicationUpdater();

        File dest = new File(config.getTuttiBasedir(), "NEW");
        ProgressionModel progressionModel = new ProgressionModel();
        getContext().getActionUI().getModel().setProgressionModel(progressionModel);
        progressionModel.setMessage("Recherche de mises à jour de base");
        TuttiApplicationUpdaterCallBack callback = new TuttiApplicationUpdaterCallBack(getContext(), progressionModel);
        callback.setTypes(TuttiApplicationUpdaterCallBack.UpdateType.DB);
        up.update(url,
                  current,
                  dest,
                  false,
                  callback);

        if (callback.isDbUpdated()) {

            progressionModel.setMessage("Rechargement de la base de données");

            getContext().setDbLoaded(true);
            getContext().reloadPersistenceService();


        } else {
            sendMessage("Aucune mise à jour de base détectée.");
        }
    }

    @Override
    protected void releaseAction(ActionEvent event) {
        getContext().getActionUI().getModel().setProgressionModel(null);
        super.releaseAction(event);
    }
}

==> tutti-ui-swing-1.0.1-sources.jar: fr/ifremer/tutti/ui/swing/UpdateReferentialAction.java <==
package fr.ifremer.tutti.ui.swing;

/*
 * #%L
 * Tutti :: UI
 * $Id: UpdateReferentialAction.java 438 2013-02-18 07:40:56Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.0.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/UpdateReferentialAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.persistence.ProgressionModel;
import fr.ifremer.tutti.ui.swing.config.TuttiApplicationConfig;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.nuiton.util.ApplicationUpdater;

import java.awt.event.ActionEvent;
import java.io.File;

import static org.nuiton.i18n.I18n._;

/**
 * To update referential using the {@link ApplicationUpdater} mecanism.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class UpdateReferentialAction extends AbstractMainUITuttiAction {

    private static final long serialVersionUID = 1L;

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(UpdateReferentialAction.class);

    public UpdateReferentialAction(MainUIHandler handler) {
        super(handler,
              "updateReferential",
              "update-referential",
              _("tutti.action.updateReferential"),
              _("tutti.action.updateReferential.tip"),
              true);
    }

    @Override
    protected void doAction(ActionEvent event) {
        TuttiApplicationConfig config = getContext().getConfig();

        File current = config.getDataDirectory();
        String url = config.getUpdateUrl();

        if (log.isInfoEnabled()) {
            log.info(String.format("Try to update db (current data location: %s), using update url: %s", current, url));
        }
        ApplicationUpdater up = new ApplicationUpdater();

        File dest = new File(config.getTuttiBasedir(), "NEW");
        ProgressionModel progressionModel = new ProgressionModel();
        getContext().getActionUI().getModel().setProgressionModel(progressionModel);
        progressionModel.setMessage("Recherche de mises à jour de base");
        TuttiApplicationUpdaterCallBack callback = new TuttiApplicationUpdaterCallBack(getContext(), progressionModel);
        callback.setTypes(TuttiApplicationUpdaterCallBack.UpdateType.DB);
        up.update(url,
                  current,
                  dest,
                  false,
                  callback);

        if (callback.isDbUpdated()) {

            progressionModel.setMessage("Rechargement de la base de données");

            getContext().setDbLoaded(true);
            getContext().reloadPersistenceService();


        } else {
            sendMessage("Aucune mise à jour de base détectée.");
        }
    }

    @Override
    protected void releaseAction(ActionEvent event) {
        getContext().getActionUI().getModel().setProgressionModel(null);
        super.releaseAction(event);
    }
}
